@@ -24,15 +24,16 @@ module Aws
       end
 
       # When a client is stubbed allow the user to access the requests made
-      @api_requests = []
-
-      requests = @api_requests
+      requests = @api_requests = []
+      requests_mutex = @requests_mutex = Mutex.new
       self.handle do |context|
-        requests << {
-          operation_name: context.operation_name,
-          params: context.params,
-          context: context
-        }
+        requests_mutex.synchronize do
+          requests << {
+            operation_name: context.operation_name,
+            params: context.params,
+            context: context
+          }
+        end
         @handler.call(context)
       end
     end
@@ -194,10 +195,12 @@ module Aws
     #   is not stubbed.
     def api_requests(options = {})
       if config.stub_responses
-        if options[:exclude_presign]
-          @api_requests.reject {|req| req[:context][:presigned_url] }
-        else
-          @api_requests
+        @requests_mutex.synchronize do
+          if options[:exclude_presign]
+            @api_requests.reject {|req| req[:context][:presigned_url] }
+          else
+            @api_requests
+          end
         end
       else
         msg = 'This method is only implemented for stubbed clients, and is '\
